==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/dsl/camel-jbang/camel-jbang-core/src/main/java/org/apache/camel/dsl/jbang/core/commands/config/ConfigGet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dsl.jbang.core.commands.config;

import java.util.Optional;

import org.apache.camel.dsl.jbang.core.commands.CamelCommand;
import org.apache.camel.dsl.jbang.core.commands.CamelJBangMain;
import org.apache.camel.dsl.jbang.core.common.CommandLineHelper;
import picocli.CommandLine;

@CommandLine.Command(name = "get",
                     description = "Display user configuration value", sortOptions = false, showDefaultValues = true)
public class ConfigGet extends CamelCommand {

    @CommandLine.Parameters(description = "Configuration key", arity = "1")
    String key;

    public ConfigGet(CamelJBangMain main) {
        super(main);
    }

    @Override
    public Integer doCall() throws Exception {
        CommandLineHelper.loadProperties(properties -> {
            Optional<Object> maybeProperty = Optional.ofNullable(properties.get(key));
            if (maybeProperty.isPresent()) {
                printer().println(String.valueOf(maybeProperty.get()));
            } else {
                printer().println(key + " key not found");
            }
        });

        return 0;
    }
}

==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/dsl/camel-jbang/camel-jbang-core/src/main/java/org/apache/camel/dsl/jbang/core/commands/config/ConfigGet.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dsl.jbang.core.commands.config;

import java.util.Optional;

import org.apache.camel.dsl.jbang.core.commands.CamelCommand;
import org.apache.camel.dsl.jbang.core.commands.CamelJBangMain;
import org.apache.camel.dsl.jbang.core.common.CommandLineHelper;
import picocli.CommandLine;

@CommandLine.Command(name = "get",
                     description = "Display user configuration value", sortOptions = false, showDefaultValues = true)
public class ConfigGet extends CamelCommand {

    @CommandLine.Parameters(description = "Configuration key", arity = "1")
    String key;

    @CommandLine.Option(names = { "--global" }, description = "Use global or local configuration")
    boolean global = true;

    public ConfigGet(CamelJBangMain main) {
        super(main);
    }

    @Override
    public Integer doCall() throws Exception {
        CommandLineHelper.loadProperties(properties -> {
            Optional<Object> maybeProperty = Optional.ofNullable(properties.get(key));
            if (maybeProperty.isPresent()) {
                printer().println(String.valueOf(maybeProperty.get()));
            } else {
                printer().println(key + " key not found");
            }
        }, !global);

        return 0;
    }
}
